/*  
 *  - - - - - - - - - - - - -
 *   g a l _ f r a m e s . h
 *  - - - - - - - - - - - - -
 *  
 *  This header file is part of the General Astrodynamics Library  
 *
 *  Description:
 *
 *     This header file includes all of the component header files
 *     for the reference frames sub-library.
 *  
 *  Status: 
 *  
 *     Sub-library header file  
 *
 *  Includes:  
 *
 *     gal_t2azel.h                   ITRF -> Azimuth & Elevation
 *     gal_t2latlon.h                 ITRF -> Geodetic Latitude & Longitude
 *     gal_t2latlonf.h                ITRF -> Geodetic Latitude & Longitude ( alt )
 *     gal_t2latlon_iers00.h          ITRF -> Geodetic Latitude & Longitude ( alt ) IERS2000
 *     gal_t2latlon_iau76.h           ITRF -> Geodetic Latitude & Longitude ( alt ) IAU76
 *     gal_t2latlon_wgs72.h           ITRF -> Geodetic Latitude & Longitude ( alt ) WGS72
 *     gal_t2latlon_wgs84.h           ITRF -> Geodetic Latitude & Longitude ( alt ) WGS84
 *     gal_latlon2t.h                 Geodetic Latitude & Longitude -> ITRF
 *     gal_latlon2t_iau76.h           Geodetic Latitude & Longitude -> ITRF IAU76
 *     gal_latlon2t_iers00.h          Geodetic Latitude & Longitude -> ITRF IERS2000
 *     gal_latlon2t_wgs84.h           Geodetic Latitude & Longitude -> ITRF WGS84
 *     gal_latlon2t_wgs72.h           Geodetic Latitude & Longitude -> ITRF WGS72
 *     gal_c2radec.h                  GCRF -> RA & Dec
 *     gal_c2tpv00a.h                 GCRF -> ITRF Position & Velocity IAU2000A
 *     gal_c2tpv00b.h                 GCRF -> ITRF Position & Velocity IAU2000B
 *     gal_c2tpv06a.h                 GCRF -> ITRF Position & Velocity IAU2006A
 *     gal_i2tpv00.h                  Intermediate -> ITRF Position & Velocity
 *     gal_t2ipv00.h                  ITRF -> Intermediate Position & Velocity
 *     gal_t2cpv00a.h                 ITRF -> GCRF Position & Velocity IAU2000A
 *     gal_t2cpv00b.h                 ITRF -> GCRF Position & Velocity IAU2000B
 *     gal_t2cpv06a.h                 ITRF -> GCRF Position & Velocity IAU2006A
 *
 *  This revision:  
 * 
 *     2008 May 25  
 *  
 *  Copyright (C) 2008 Paul C. L. Willmott. See notes at end. 
 *  
 *-----------------------------------------------------------------------  
 */  

#ifndef _GAL_FRAMES_H_  
#define _GAL_FRAMES_H_ 1  
  
#include "gal_t2azel.h"
#include "gal_t2latlon.h"
#include "gal_t2latlonf.h"
#include "gal_t2latlon_iers00.h"
#include "gal_t2latlon_wgs84.h"
#include "gal_t2latlon_wgs72.h"
#include "gal_t2latlon_iau76.h"
#include "gal_latlon2t.h"
#include "gal_latlon2t_iers00.h"
#include "gal_latlon2t_wgs84.h"
#include "gal_latlon2t_wgs72.h"
#include "gal_latlon2t_iau76.h"
#include "gal_c2radec.h"
#include "gal_c2tpv00a.h"
#include "gal_c2tpv00b.h"
#include "gal_c2tpv06a.h"
#include "gal_i2tpv00.h"
#include "gal_t2ipv00.h"
#include "gal_t2cpv00a.h"
#include "gal_t2cpv00b.h"
#include "gal_t2cpv06a.h"

#endif /* !_GAL_FRAMES_H_ */ 

/*
 *  gal - General Astrodynamics Library  
 *  Copyright (C) 2008 Paul C. L. Willmott  
 *  
 *  This program is free software; you can redistribute it and/or modify  
 *  it under the terms of the GNU General Public License as published by  
 *  the Free Software Foundation; either version 2 of the License, or  
 *  (at your option) any later version.  
 *  
 *  This program is distributed in the hope that it will be useful,  
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of  
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the  
 *  GNU General Public License for more details.  
 *  
 *  You should have received a copy of the GNU General Public License along  
 *  with this program; if not, write to the Free Software Foundation, Inc.,  
 *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.  
 *    
 *  Contact:  
 *    
 *  Paul Willmott  
 *  vp9mu@amsat.org  
 */  
  